@@ -24,24 +24,29 @@
  * 		350 North Bernardo Ave.
  * 		Mountain View, CA  94043
  *
- * $NCDId: @(#)audemo.c,v 1.59 1995/10/18 19:39:54 greg Exp $
+ * $NCDId: @(#)audemo.c,v 1.60 1995/12/06 01:08:33 greg Exp $
  */
+#include "config.h"
 
 #include <stdio.h>
-#ifdef __STDC__
-#include <stdlib.h>
-#endif
-#include <signal.h>
-#include <malloc.h>
 
-#ifndef SYSV
+#if defined(HAVE_STDLIB_H)
+# include <stdlib.h> 
+#endif
+
+#if defined(HAVE_MALLOC_H)
+# include <malloc.h>
+#endif
+
+#include <signal.h>
+#if !defined(SYSV) || defined(WIN32)
 #include <audio/Aos.h>		/* for string and other os stuff */
 #endif
 #include <audio/Afuncs.h>	/* for bcopy et. al. */
 #include <audio/audiolib.h>
 #include <audio/soundlib.h>
 
-#ifdef SYSV  
+#if defined(SYSV) && !defined(WIN32)
 #include <sys/time.h>		/* for timeval */
 
 /* not defined in <stdio.h> when -Xc used */
@@ -53,6 +58,10 @@ popen(
 );
 #endif						/* SVR4 */
 
+#ifdef WIN32
+#include <winsock.h>
+#endif /* WIN32 */
+
 #define AddToLinkedList(head, item)					       \
 {									       \
     (item)->prev = NULL;						       \
@@ -255,7 +264,7 @@ static ElementListPtr ElementList;
 static int      ElementCount,
                 MonitorCount;
 
-#ifndef sun					/* who else doesn't have
+#if !defined(sun) && !defined(linux)		/* who else doesn't have
 						 * this? */
 #define strdup ncd_strdup			/* To avoid conflicting with
 						 * headers on hosts that *do*
@@ -1851,7 +1860,11 @@ int             nfiles;
 
     for (i = 0; i < nfiles; i++)
     {
-	p = strrchr(fileNames[i], '/') + 1;
+      if (p = strrchr(fileNames[i], '/')) 
+        p++;
+      else
+        p = fileNames[i];
+      
 	fileList[i] = (char *) strdup(p);
 
 	if ((p = strrchr(fileList[i], '.')))
@@ -1866,6 +1879,7 @@ int             nfiles;
     return fileList;
 }
 
+#ifndef WIN32
 static FILE    *
 startFind(dir, template)
 char           *dir,
@@ -1904,6 +1918,7 @@ char           *dir,
     free(cmd);
     return fp;
 }
+#endif /* !WIN32 */
 
 static int
 getFileNames(dir, fileNames, template)
@@ -1911,6 +1926,7 @@ char           *dir,
              ***fileNames,
                *template;
 {
+#ifndef WIN32
     int             files;
     FILE           *fp;
     char            line[BUF_SIZE];
@@ -1947,4 +1963,60 @@ char           *dir,
 	free(*fileNames);
 
     return files;
+#else /* WIN32 */
+    WIN32_FIND_DATA fileInfo;
+    char *d;
+    int files = 0;
+    HANDLE h;
+
+    *fileNames = NULL;
+    if (!(d = (char *) malloc(strlen(dir) + 5)))
+	return 0;
+
+    strcpy(d, dir);
+    strcat(d, "/*.*");
+    h = FindFirstFile(d, &fileInfo);
+    free(d);
+
+    if (!h)
+	return 0;
+
+    do
+    {
+	if (!(fileInfo.dwFileAttributes &
+	      (FILE_ATTRIBUTE_DIRECTORY | FILE_ATTRIBUTE_SYSTEM)))
+	{
+	    char *p = NULL;
+
+	    if (p = (char *) malloc(strlen(dir) + strlen(fileInfo.cFileName) +
+				    2))
+	    {
+		*fileNames = (char **) realloc(*fileNames, sizeof(char *) *
+					       (files + 1));
+		strcpy(p, dir);
+		strcat(p, "/");
+		strcat(p, fileInfo.cFileName);
+
+		(*fileNames)[files++] = p;
+	    }
+	}
+    } while(FindNextFile(h, &fileInfo));
+
+    FindClose(h);
+    return files;
+#endif /* WIN32 */
 }
+
+#ifdef WIN32
+#include <sys/timeb.h>
+
+int
+gettimeofday(struct timeval *tv, void *dummy)
+{
+    struct _timeb tm;
+    _ftime(&tm);
+    tv->tv_sec = tm.time;
+    tv->tv_usec = tm.millitm;
+    return 0;
+}
+#endif /* WIN32 */
