@@ -19,7 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $Id: auhpux.c,v 1.7 2000/01/02 03:35:44 jon Exp $
+ * $Id: auhpux.c,v 1.8 2002/07/12 04:44:15 jon Exp $
  * $NCDId: @(#)auhpux.c,v 1.3 1996/04/24 17:18:13 greg Exp $
  */
 
@@ -61,7 +61,7 @@
 #include <audio/Aproto.h>
 #include <errno.h>
 
-#include "nasconfig.h"
+#include "nasconf.h"
 #include "dixstruct.h"				/* for RESTYPE */
 #include "os.h"					/* for xalloc/xfree and NULL */
 #include "au.h"
