@@ -1,4 +1,4 @@
-/* $Id: auvoxware.c,v 1.13 2001/04/30 00:11:07 jon Exp $ */
+/* $Id: auvoxware.c,v 1.29 2006/05/17 00:51:42 jon Exp $ */
 
 /*
    SCCS: @(#) auvoxware.c 11.4 95/04/14 
@@ -133,7 +133,24 @@ PERFORMANCE OF THIS SOFTWARE.
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "nasconfig.h"
+#ifndef SVR4
+#include <getopt.h>
+#endif
+#include <sys/types.h>
+#include <errno.h>
+#ifndef _POSIX_SOURCE
+# include <sys/ioctl.h>
+#endif
+
+#if defined(__CYGWIN__)
+# ifndef O_SYNC
+#  define O_SYNC          _FSYNC
+# endif
+extern int errno;
+#endif
+
+
+#include "nasconf.h"
 #include "config.h"
 #include "aulog.h"
 
@@ -154,8 +171,17 @@ static int debug_msg_indentation = 0;
 #include <sys/param.h>
 #include <assert.h>
 
-#ifdef __FreeBSD__
-# include <machine/soundcard.h>
+#if defined(__DragonFly__)
+#  include <sys/soundcard.h>
+#  ifndef O_SYNC
+#     define O_SYNC O_FSYNC
+#  endif
+#elif defined(__FreeBSD__)
+# if __FreeBSD_version >= 500001 
+#  include <sys/soundcard.h> 
+# else
+#  include <machine/soundcard.h>
+# endif
 # include <machine/pcaudioio.h>
 #else
 # ifdef __NetBSD__
@@ -183,9 +209,6 @@ static void closeDevice(void);
 #define MIN_MINIBUF_SAMPLES	256
 #define MAX_MINIBUF_SAMPLES     1024     /* Must be a power of 2 */
 
-#define auDefaultInputGain	AuFixedPointFromSum(50, 0)
-#define auDefaultOutputGain	AuFixedPointFromSum(50, 0)
-
 #define	PhysicalOneTrackBufferSize \
     PAD4(auMinibufSamples * auNativeBytesPerSample * 1)
 #define	PhysicalTwoTrackBufferSize \
@@ -226,10 +249,15 @@ SndStat sndStatIn =
 	32,			/* maxFrags */
 	"/dev/dsp1",		/* device */
 	"/dev/mixer1",		/* mixer */
+#if defined(__CYGWIN__)
 	O_RDONLY,		/* howToOpen */
+#else
+	O_RDWR,			/* howToOpen */
+#endif
 	1,			/* autoOpen */
 	0,			/* forceRate */
-	0			/* isPCSpeaker */
+	0,			/* isPCSpeaker */
+	50			/* default gain */
 }, sndStatOut =
 {
 	-1,			/* fd */
@@ -243,12 +271,20 @@ SndStat sndStatIn =
 	32,			/* maxFrags */
 	"/dev/dsp",		/* device */
 	"/dev/mixer",		/* mixer */
+#if defined(__CYGWIN__)
+	O_WRONLY,		/* howToOpen */
+#else
 	O_RDWR,			/* howToOpen */
+#endif
 	1,			/* autoOpen */
 	0,			/* forceRate */
-	0			/* isPCSpeaker */
+	0,			/* isPCSpeaker */
+	50			/* default gain */
 };
 
+#define auDefaultInputGain	AuFixedPointFromSum(sndStatIn.gain, 0)
+#define auDefaultOutputGain	AuFixedPointFromSum(sndStatOut.gain, 0)
+
 static AuUint8 *auOutputMono,
                *auOutputStereo,
                *auInput;
@@ -482,7 +518,7 @@ AuUint32 *auServerDeviceListSize,
 static AuInt32 setTimer(rate)
 AuInt32 rate;
 {
-  AuInt16          timer_ms;
+  AuInt32          timer_ms;
   AuInt32          foo;
   struct itimerval ntval, otval;
 
@@ -498,7 +534,7 @@ AuInt32 rate;
     ntval.it_interval.tv_sec = ntval.it_interval.tv_usec = 0;
     timer_ms = 0x7fff;
   } else {
-    timer_ms = (auMinibufSamples * 700) / rate;
+    timer_ms = (auMinibufSamples * 500) / rate;
     ntval.it_interval.tv_sec = 0;
     ntval.it_interval.tv_usec = timer_ms * 1000;
     ntval.it_value.tv_sec = 0;
@@ -561,6 +597,10 @@ AuUint32 rate;
   int numSamplesIn, numSamplesOut;
   AuBlock l;
 
+  setTimer(0);                  /* JET - turn off the timer here so the
+                                   following code has a chance to clean
+                                   things up. A race can result
+                                   otherwise.  */
   if (NasConfig.DoDebug)
     {
       osLogMsg("setSampleRate(rate = %d);\n", rate);
@@ -613,6 +653,15 @@ static AuBool
 openDevice(wait)
 AuBool wait;
 {
+  unsigned int extramode = 0;
+  int retries;
+
+  setTimer(0);                  /* no timers here */
+#if defined(__CYGWIN__)		/* we want the file to be created if necc under
+				   windows */
+  extramode = O_CREAT;
+#endif
+
   if (NasConfig.DoDebug)
     {
       osLogMsg("openDevice\n");
@@ -622,84 +671,102 @@ AuBool wait;
     osLogMsg("openDevice OUT %s mode %d\n", 
 	     sndStatOut.device, sndStatOut.howToOpen);
 
-    if(sndStatOut.fd == -1)
+  
+  if(sndStatOut.fd == -1)
     {
-       while ((sndStatOut.fd = open(sndStatOut.device, sndStatOut.howToOpen|O_SYNC, 0666)) == -1 && wait)
-       {
-           osLogMsg("openDevice: waiting on output device\n");
-           sleep(1);
-       }
-       setupSoundcard(&sndStatOut);
+      while ((sndStatOut.fd = open(sndStatOut.device, 
+                                   sndStatOut.howToOpen|O_SYNC|extramode, 
+                                   0666)) == -1 && wait)
+        {
+          osLogMsg("openDevice: waiting on output device\n");
+          sleep(1);
+        }
+      setupSoundcard(&sndStatOut);
     }
-    else
-      {
-	if (NasConfig.DoDebug)
-	  {
-	    osLogMsg("openDevice: output device already open\n");
-	  }
-      }
-
-    if(sndStatIn.fd == -1 && !share_in_out)
+  else
+    {
+      if (NasConfig.DoDebug)
+        {
+          osLogMsg("openDevice: output device already open\n");
+        }
+    }
+  
+#if  !defined(__CYGWIN__) 
+  if(sndStatIn.fd == -1 && !share_in_out)
     {
       if (NasConfig.DoDebug)
 	osLogMsg("openDevice IN %s mode %d\n", sndStatIn.device, 
 		 sndStatIn.howToOpen);
-
-       while ((sndStatIn.fd = open(sndStatIn.device, sndStatIn.howToOpen, 0)) == -1 && wait)
-       {
-           osLogMsg("openDevice: waiting on input device\n");
-           sleep(1);
-       }
-       if (sndStatOut.fd != sndStatIn.fd)
-           setupSoundcard(&sndStatIn);
+      
+      retries = 0;
+      while ((sndStatIn.fd = open(sndStatIn.device, 
+                                  sndStatIn.howToOpen|extramode, 
+                                  0666)) == -1 && wait)
+        {
+          osLogMsg("openDevice: waiting on input device, retry %d\n",
+                   retries);
+          sleep(1);
+          retries++;
+          
+          if (retries >= 5)
+            {
+              osLogMsg("openDevice: maximum retries exceeded, giving up\n");
+              sndStatIn.fd = -1;
+              break;
+            }
+        }
+      if (sndStatIn.fd != -1 && sndStatOut.fd != sndStatIn.fd)
+        setupSoundcard(&sndStatIn);
     }
-    else
+  else
     {
-       sndStatIn.fd=sndStatOut.fd;
-       if (NasConfig.DoDebug)
-	 {
-	   osLogMsg("openDevice: input device already open\n");
-	 }
+      sndStatIn.fd=sndStatOut.fd;
+      if (NasConfig.DoDebug)
+        {
+          osLogMsg("openDevice: input device already open\n");
+        }
     }
-
-    if(mixerfd == -1)
-       while ((mixerfd = open(sndStatOut.mixer, O_RDONLY, 0)) == -1 && wait)
-       {
-           osLogMsg("openDevice: waiting on mixer device\n");
-           sleep(1);
-       }
-    else
+  
+  if(mixerfd == -1)
+    while ((mixerfd = open(sndStatOut.mixer, O_RDONLY|extramode, 
+                           0666)) == -1 && wait)
       {
-	if (NasConfig.DoDebug)
-	  {
-	    osLogMsg("openDevice: mixer device already open\n");
-	  }
+        osLogMsg("openDevice: waiting on mixer device\n");
+        sleep(1);
       }
-
-    ioctl(sndStatOut.fd, SNDCTL_DSP_SYNC, NULL);
-
+  else
     {
-      int rate ;
-#ifndef sco
-      rate = sndStatOut.curSampleRate ;
-      ioctl(sndStatOut.fd, SNDCTL_DSP_SPEED, &sndStatOut.curSampleRate);
-      if (sndStatOut.forceRate) sndStatOut.curSampleRate = rate ;
-#endif /* sco */
-
-      if (sndStatOut.fd != sndStatIn.fd)
-	{
-	  ioctl(sndStatIn.fd, SNDCTL_DSP_SYNC, NULL);
-#ifndef sco
-	  rate = sndStatOut.curSampleRate ;
-	  ioctl(sndStatIn.fd, SNDCTL_DSP_SPEED, &sndStatIn.curSampleRate);
-	  if (sndStatIn.forceRate) sndStatIn.curSampleRate = rate ;
-#endif /* sco */
-	}
+      if (NasConfig.DoDebug)
+        {
+          osLogMsg("openDevice: mixer device already open\n");
+        }
     }
-    
-    setSampleRate(sndStatIn.curSampleRate);
+#endif
 
-    return AuTrue;
+  ioctl(sndStatOut.fd, SNDCTL_DSP_SYNC, NULL);
+  
+  {
+    int rate ;
+#ifndef sco
+    rate = sndStatOut.curSampleRate ;
+    ioctl(sndStatOut.fd, SNDCTL_DSP_SPEED, &sndStatOut.curSampleRate);
+    if (sndStatOut.forceRate) sndStatOut.curSampleRate = rate ;
+#endif /* sco */
+    
+    if (sndStatOut.fd != sndStatIn.fd)
+      {
+        ioctl(sndStatIn.fd, SNDCTL_DSP_SYNC, NULL);
+#ifndef sco
+        rate = sndStatOut.curSampleRate ;
+        ioctl(sndStatIn.fd, SNDCTL_DSP_SPEED, &sndStatIn.curSampleRate);
+        if (sndStatIn.forceRate) sndStatIn.curSampleRate = rate ;
+#endif /* sco */
+      }
+  }
+  
+  setSampleRate(sndStatIn.curSampleRate);
+  
+  return AuTrue;
 }
 
 static void
@@ -716,7 +783,6 @@ closeDevice()
 	  osLogMsg("closeDevice: output device already closed\n");
 	}
     }
-
     else
     {
       if (NasConfig.DoDebug)
@@ -836,7 +902,7 @@ intervalProc()
 #ifndef sco
 	signal(SIGALRM, SIG_IGN);
 
-#if defined(linux) 
+#if defined(linux) || defined(__CYGWIN__)
        /* this looks funny and stupid, but BSD not only provide
         * reliable signals but also block this signal while executing
         * this handler
@@ -861,7 +927,7 @@ intervalProc()
 #endif /* sco */
 		AuProcessData();
 #ifndef sco
-#if defined(linux)
+#if defined(linux) || defined(__CYGWIN__)
                 /* block the signal again */
                 {
                         sigset_t set;
@@ -897,8 +963,7 @@ setPhysicalOutputGain(gain)
     Letsplay = g;
     gusvolume = g | (g << 8);
     if (mixerfd != -1)
-        if(!leave_mixer)
-	i = ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_PCM), &gusvolume);
+      i = ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_PCM), &gusvolume);
 }
 
 static          AuFixedPoint
@@ -962,7 +1027,7 @@ static void enableProcessFlow()
 	signal(SIGALRM, intervalProc);
 	if (NasConfig.DoDebug > 1)
 	  {
-	    osLogMsg("enableProcessFlow() - set SIGALRM handler to intervalProc");
+	    osLogMsg("enableProcessFlow() - set SIGALRM handler to intervalProc\n");
 	  }
 #else
 	setTimer(sndStatOut.curSampleRate);
@@ -977,8 +1042,8 @@ static void disableProcessFlow()
 {
 
 #ifndef sco
-int rate ;
-	signal(SIGALRM, SIG_IGN);
+  int rate ;
+  signal(SIGALRM, SIG_IGN);
 #endif /* sco */
 
   if (NasConfig.DoDebug)
@@ -1028,7 +1093,7 @@ int rate ;
 }
 
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL)
+#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
 static void monoToStereoLinearSigned16LSB(numSamples)
@@ -1043,7 +1108,7 @@ AuUint32 numSamples;
   }
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL)
+#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
 static void monoToStereoLinearUnsigned8(numSamples)
@@ -1104,7 +1169,7 @@ static void writePhysicalOutputsMono()
   AuUnBlockAudio(l);
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL)
+#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
 static void stereoToMonoLinearSigned16LSB(numSamples)
@@ -1119,7 +1184,7 @@ AuUint32 numSamples;
   }
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL)
+#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
 static void stereoToMonoLinearUnsigned8(numSamples)
@@ -1280,19 +1345,21 @@ SndStat* sndStatPtr;
       IDENTMSG;
     }
 
-  if (NasConfig.DoVerbose)
+  if (NasConfig.DoDebug)
     if (sndStatPtr == &sndStatOut)
     {
-       osLogMsg("++ Setting up Output device\n");
+       osLogMsg("++ Setting up Output device (%s)\n",
+                sndStatPtr->device);
     }
     else
     {
-       osLogMsg("++ Setting up Input device\n");
+       osLogMsg("++ Setting up Input device (%s)\n",
+                sndStatPtr->device);
     }
 
 	
   if (sndStatPtr->isPCSpeaker) {
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("+++ Device is a PC speaker\n");
     sndStatPtr->curSampleRate = sndStatPtr->maxSampleRate
       = sndStatPtr->minSampleRate = 8000;
@@ -1300,36 +1367,36 @@ SndStat* sndStatPtr;
     sndStatPtr->wordSize = 8;
   }
   else {
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("+++ requesting wordsize of %d, ", sndStatPtr->wordSize);
     if (ioctl(sndStatPtr->fd, SNDCTL_DSP_SAMPLESIZE, &sndStatPtr->wordSize)
         || sndStatPtr->wordSize != 16) {
       sndStatPtr->wordSize = 8;
       ioctl(sndStatPtr->fd, SNDCTL_DSP_SAMPLESIZE, &sndStatPtr->wordSize);
     }
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("got %d\n", sndStatPtr->wordSize);
   
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("+++ requesting %d channel(s), ", sndStatPtr->isStereo + 1);
     if (ioctl(sndStatPtr->fd, SNDCTL_DSP_STEREO, &sndStatPtr->isStereo) == -1
         || !sndStatPtr->isStereo) {
       sndStatPtr->isStereo = 0;
       ioctl(sndStatPtr->fd, SNDCTL_DSP_STEREO, &sndStatPtr->isStereo);
     }
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("got %d channel(s)\n", sndStatPtr->isStereo + 1);
 
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("+++ Requesting minimum sample rate of %d, ", sndStatPtr->minSampleRate);
     ioctl(sndStatPtr->fd, SNDCTL_DSP_SPEED, &sndStatPtr->minSampleRate);
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("got %d\n", sndStatPtr->minSampleRate);
   
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("+++ Requesting maximum sample rate of %d, ", sndStatPtr->maxSampleRate);
     ioctl(sndStatPtr->fd, SNDCTL_DSP_SPEED, &sndStatPtr->maxSampleRate);
-    if (NasConfig.DoVerbose)
+    if (NasConfig.DoDebug)
       osLogMsg("got %d\n", sndStatPtr->maxSampleRate);
 
     sndStatPtr->curSampleRate = sndStatPtr->maxSampleRate;
@@ -1364,6 +1431,83 @@ scoInterrupts()
 }
 #endif /* sco */
 
+static AuBool initMixer()
+{
+  unsigned int extramode = 0;
+  AuInt32 i;
+
+#if defined(__CYGWIN__)		/* we want the file to be created if necc under
+				   windows */
+  extramode = O_CREAT;
+#endif
+
+  if ((mixerfd = open(sndStatOut.mixer, O_RDONLY|extramode, 
+    		  0666)) == -1) {
+    UNIDENTMSG;
+    return AuFalse;
+  }
+  
+  if (ioctl(mixerfd, SOUND_MIXER_READ_DEVMASK, &devmask) == -1) {
+    close(mixerfd);
+    mixerfd = -1;
+  } else {
+    if (ioctl(mixerfd, SOUND_MIXER_READ_RECMASK, &recmask) == -1) {
+      return AuFalse;
+    }
+  
+    {
+      /* Enable all used recording sources ( mic & line ) and
+       * control which is active via level setting later. There
+       * should be a better way to do this!
+       */
+     if (!leave_mixer)
+     {
+       int mask = SOUND_MASK_MIC | SOUND_MASK_LINE; /* enable these */
+       mask &= recmask;    /* if supported */
+       if (ioctl(mixerfd, SOUND_MIXER_WRITE_RECSRC, &mask) == -1) 
+         {
+           osLogMsg("%s: ioctl(SOUND_MIXER_WRITE_RECSRC) failed: %s\n",
+                    sndStatOut.mixer,
+                    strerror(errno));
+           /*                return AuFalse; - no need to exit here..*/
+         }
+     }
+    }
+
+    if (ioctl(mixerfd, SOUND_MIXER_READ_RECSRC, &recsrc) == -1) {
+      UNIDENTMSG;
+      osLogMsg("%s: ioctl(SOUND_MIXER_READ_RECSRC) failed: %s\n",
+               sndStatOut.mixer,
+                 strerror(errno));
+      recsrc = 0;
+      /* 	  return AuFalse; - let's not be too hasty */
+    }
+  
+    if (ioctl(mixerfd, SOUND_MIXER_READ_STEREODEVS, &stereodevs) == -1) {
+      UNIDENTMSG;
+      osLogMsg("%s: ioctl(SOUND_MIXER_READ_STEREODEVS) failed: %s\n",
+               sndStatOut.mixer,
+                 strerror(errno));
+      return AuFalse;
+    }
+  
+    /* get all sound levels */
+    for (i = 0; i < SOUND_MIXER_NRDEVICES; i++) {
+      if ((1 << i) & devmask) {
+      
+        if (ioctl(mixerfd, MIXER_READ(i), &level[i]) == -1) {
+          UNIDENTMSG;
+          osLogMsg("%s: ioctl(MIXER_READ(%d)) failed: %s\n",
+                   sndStatOut.mixer,
+                   i,
+                   strerror(errno));
+          return AuFalse;
+        }
+      }
+    }
+  }
+}
+      
 AuBool AuInitPhysicalDevices()
 {
   static AuBool    AL_initialized = AuFalse;
@@ -1374,10 +1518,15 @@ AuBool AuInitPhysicalDevices()
   extern AuUint32  auPhysicalOutputBuffersSize;
   extern void      AuProcessData();
   char            *nas_device_policy;
+  unsigned int    extramode = 0; /* for extra open modes (cygwin) */
 #if defined(AUDIO_GETINFO)
   audio_info_t     spkrinf;
 #endif
 
+#if defined(__CYGWIN__)
+  extramode = O_CREAT;
+#endif
+
   if (NasConfig.DoDebug)
     {
       osLogMsg("AuInitPhysicalDevices();\n");
@@ -1425,9 +1574,13 @@ AuBool AuInitPhysicalDevices()
 	  osLogMsg("openDevice OUT %s mode %d\n", 
 		   sndStatOut.device, sndStatOut.howToOpen);
 	
-	if ((fd = open(sndStatOut.device, sndStatOut.howToOpen|O_SYNC, 0)) == -1)
+	if ((fd = open(sndStatOut.device, 
+		       sndStatOut.howToOpen|O_SYNC|extramode, 0)) == -1)
 	  {
 	    UNIDENTMSG;
+            osLogMsg("Output open(%s) failed: %s\n",
+                     sndStatOut.device,
+                     strerror(errno));
 	    return AuFalse;
 	  }
 	sndStatOut.fd = fd;
@@ -1454,13 +1607,17 @@ AuBool AuInitPhysicalDevices()
 	osLogMsg("openDevice(1) IN %s mode %d\n", 
 		 sndStatIn.device, sndStatIn.howToOpen);
 
-      if ((fd = open(sndStatIn.device, sndStatIn.howToOpen, 0)) != -1)
+      if ((fd = open(sndStatIn.device, sndStatIn.howToOpen|extramode, 
+		     0)) != -1)
         sndStatIn.fd = fd;
       else
       {
          sndStatIn.fd = sndStatOut.fd;
          share_in_out = AuTrue;
-      }
+         osLogMsg("Input open(%s) failed: %s, using output device\n",
+                  sndStatIn.device,
+                  strerror(errno));
+     }
     }
 
     setupSoundcard(&sndStatOut);
@@ -1468,55 +1625,10 @@ AuBool AuInitPhysicalDevices()
       setupSoundcard(&sndStatIn);
 
     if (!sndStatOut.isPCSpeaker) {
-      if ((mixerfd = open(sndStatOut.mixer, O_RDONLY, 0)) == -1) {
-        UNIDENTMSG;
-        return AuFalse;
-      }
-    
-      if (ioctl(mixerfd, SOUND_MIXER_READ_DEVMASK, &devmask) == -1) {
+      if (initMixer() == AuFalse &&
+          mixerfd != -1) {
         close(mixerfd);
-        mixerfd = -1;
-      } else {
-        if (ioctl(mixerfd, SOUND_MIXER_READ_RECMASK, &recmask) == -1) {
-	  return AuFalse;
-        }
-      
-        {
-          /* Enable all used recording sources ( mic & line ) and
-           * control which is active via level setting later. There
-           * should be a better way to do this!
-           */
-         if (!leave_mixer)
-         {
-             int mask = SOUND_MASK_MIC | SOUND_MASK_LINE; /* enable these */
-             mask &= recmask;    /* if supported */
-             if (ioctl(mixerfd, SOUND_MIXER_WRITE_RECSRC, &mask) == -1) {
-               return AuFalse;
-             }
-         }
-        }
-
-        if (ioctl(mixerfd, SOUND_MIXER_READ_RECSRC, &recsrc) == -1) {
-	  UNIDENTMSG;
-	  return AuFalse;
-        }
-      
-        if (ioctl(mixerfd, SOUND_MIXER_READ_STEREODEVS, &stereodevs) == -1) {
-	  UNIDENTMSG;
-	  return AuFalse;
-        }
-      
-        /* get all sound levels */
-        for (i = 0; i < SOUND_MIXER_NRDEVICES; i++) {
-	  if ((1 << i) & devmask) {
-	  
-	    if (ioctl(mixerfd, MIXER_READ(i), &level[i]) == -1) {
-	      UNIDENTMSG;
-	      return AuFalse;
-	    }
-	  }
-        }
-      
+	mixerfd = -1;
       }
     }
   }
