@@ -19,7 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $NCDId: @(#)WaitFor.c,v 1.9 1995/05/25 00:13:09 greg Exp $
+ * $NCDId: @(#)WaitFor.c,v 1.10 1996/04/24 17:15:18 greg Exp $
  */
 /***********************************************************
 Some portions derived from:
@@ -54,6 +54,13 @@ SOFTWARE.
  *
  *****************************************************************/
 
+#if defined(__CYGWIN__)
+#define ioctl           ioctlsocket
+#define FIOSNBIO        FIONBIO
+#include <fcntl.h>
+#include <sys/types.h>
+#endif
+
 #include <audio/audio.h>
 #include <audio/Aproto.h>
 #include <audio/Aos.h>
@@ -71,6 +78,11 @@ SOFTWARE.
 #include <assert.h>
 #endif /* _MINIX */
 
+/* JET - an attempt to get us out of a race */
+#ifdef hpux
+#define WATCHDOG 60
+#endif
+
 #include "osdep.h"
 #include "dixstruct.h"
 #include "opaque.h"
@@ -114,8 +126,6 @@ extern void CheckConnections();
 extern Bool EstablishNewConnections();
 extern void ResetOsBuffers();
 
-extern int errno;
-
 #ifdef apollo
 extern long apInputMask[];
 
@@ -134,7 +144,13 @@ extern int playback_on;
 #define signal  _local_signal
 #define sigset  _local_signal
 
+#ifndef NeedFunctionPrototypes
+static void (*_local_signal(sig, action))()
+int sig;
+void (*action)();
+#else /* NeedFunctionPrototypes */
 static void (*_local_signal(int sig, void (*action)(int)))(int)
+#endif /* NeedFunctionPrototypes */
 {
         struct sigvec   vec;
         struct sigvec   ovec;
@@ -165,7 +181,7 @@ WaitForSomething(pClientsReady)
 {
     int i;
     struct timeval waittime, *wt;
-#ifdef STARTSERVER
+#if defined(STARTSERVER) || defined(hpux)
     struct timeval wtim;
 #endif /* STARTSERVER */
     long timeout;
@@ -228,6 +244,11 @@ WaitForSomething(pClientsReady)
 			(fd_set *)LastWriteMask, (fd_set *) NULL, wt);
 #else
 #ifdef hpux
+	/* JET - 12/30/99 - let's try to time out once and awhile */
+
+	    wtim.tv_sec = WATCHDOG;
+       	    wtim.tv_usec = 0;
+	    wt = &wtim;
 
 	    i = select (MAXSOCKS, (int *)LastSelectMask,
 			(int *) NULL, (int *) NULL, wt);
